/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */

/* mpl-panel-clutter.c */
/*
 * Copyright (c) 2009 Intel Corp.
 *
 * Author: Tomas Frydrych <tf@linux.intel.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __MPL_PANEL_VERSION_H__
#define __MPL_PANEL_VERSION_H__

/**
 * MEEGO_PANEL_MAJOR_VERSION:
 *
 * The major version of the meego-panel library (1, if %MEEGO_PANEL_VERSION is 1.2.3)
 */
#define MEEGO_PANEL_MAJOR_VERSION   (0)

/**
 * MEEGO_PANEL_MINOR_VERSION:
 *
 * The minor version of the meego-panel library (2, if %MEEGO_PANEL_VERSION is 1.2.3)
 */
#define MEEGO_PANEL_MINOR_VERSION   (77)

/**
 * MEEGO_PANEL_MICRO_VERSION:
 *
 * The micro version of the meego-panel library (3, if %MEEGO_PANEL_VERSION is 1.2.3)
 */
#define MEEGO_PANEL_MICRO_VERSION   (7)

/**
 * MEEGO_PANEL_VERSION:
 *
 * The full version of the meego-panel library, like 1.2.3
 */
#define MEEGO_PANEL_VERSION         0.77.7

/**
 * MEEGO_PANEL_VERSION_S:
 *
 * The full version of the meego-panel library, in string form (suited for
 * string concatenation)
 */
#define MEEGO_PANEL_VERSION_S       "0.77.7"

/**
 * MEEGO_PANEL_VERSION_HEX:
 *
 * Numerically encoded version of the meego-panel library, like 0x010203
 */
#define MEEGO_PANEL_VERSION_HEX     ((PLUGIN_MAJOR_VERSION << 24) | \
                                 (PLUGIN_MINOR_VERSION << 16) | \
                                 (PLUGIN_MICRO_VERSION << 8))

/**
 * MEEGO_PANEL_CHECK_VERSION:
 * @major: major version, like 1 in 1.2.3
 * @minor: minor version, like 2 in 1.2.3
 * @micro: micro version, like 3 in 1.2.3
 *
 * Evaluates to %TRUE if the version of the meego-panel library is greater
 * than @major, @minor and @micro
 */
#define MEEGO_PANEL_CHECK_VERSION(major,minor,micro) \
        (MEEGO_PANEL_MAJOR_VERSION > (major) || \
         (MEEGO_PANEL_MAJOR_VERSION == (major) && MEEGO_PANEL_MINOR_VERSION > (minor)) || \
         (MEEGO_PANEL_MAJOR_VERSION == (major) && MEEGO_PANEL_MINOR_VERSION == (minor) && MEEGO_PANEL_MICRO_VERSION >= (micro)))

#endif /* __MPL_PANEL_VERSION_H__ */
